#
# spec file for package patterns-education-desktop 
#
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#

# norootforbuild

Name:           patterns-education-desktop
License:        GPL-2.0
Group:          Metapackages
Summary:        Patterns for the Education desktop project
Version:        1.7
Release:        1.7
Url:            http://en.opensuse.org/Education/Development
Vendor:         openSUSE-Education
AutoReqProv:    off
Source:         %name.tar.bz2
Source1:        patterns-education-desktop-rpmlintrc
Source2:        EXTRA_PROV
BuildRequires:  coreutils
%if 0%{?suse_version} > 1020
BuildRequires:  gzip
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# The name below will be added as global pattern name 
# in the comment header of each pattern file.
# So you can choose a "generic" one to identify all 
# your patterns later
%define         global_name "openSUSE-Education"

# since openSUSE 11.0 all patterns are collected in 
# one big pattern file - so this name must be different 
# from the ones in the tarball
%define         all_in_one_pattern_name all-%{name}

# if you need 32bit packages (and patterns), 
# set the macro below to 1
%define         create_xxbit_pattern 0

# to get a list of all packages for product config, define 1 below
%define         create_packagelist 1

# FYI: "Ord" must be unique - so we must have one for each pattern file
# and architecture. You only need to define the first number (for
# i386 - the rest should be done automatically.

%description
Pattern files for the Education desktop Add on CD.


Authors:
--------
    Lars Vogdt

%prep
%setup -q -n %name

%build

%install
#
# Enviroment
#
rm -Rf %buildroot
mkdir %buildroot
mkdir -p %buildroot/CD1/suse/setup/descr
mkdir -p %buildroot/%_datadir/%name/repodata
install -m644 %{SOURCE2} %buildroot/CD1/suse/setup/descr/

#
# Patterns
#
TMPFILE=`mktemp /tmp/%{name}-XXXXXX`
YEAR=`date "+%Y"`

# EXTENSION defines xxbit packages (and patterns)
EXTENSION=""

function create_pattern(){
  for patname in $(ls -d *); do
    test -f $TMPFILE && rm $TMPFILE
    pushd $patname 1>/dev/null

	# Ordernumber must defined and unique
	ORDERNUMBER=$(cat Ord)
	if [ x"$ORDERNUMBER" = x"" ]; then
		echo "Ordernumber not defined"
		exit 1
	fi
	# EXTENSION defines xxbit packages (and patterns)
	%ifarch ia64
	  ORDERNUMBER=$((ORDERNUMBER+1))
	%endif
	%ifarch ppc
	  ORDERNUMBER=$((ORDERNUMBER+2))
	%endif
	%ifarch ppc64
	  ORDERNUMBER=$((ORDERNUMBER+3))
	%endif
	%ifarch s390x
	  ORDERNUMBER=$((ORDERNUMBER+4))
	%endif
	%ifarch x86_64
	  ORDERNUMBER=$((ORDERNUMBER+5))
	%endif
	if [ "$EXTENSION" != "" ]; then
		# TODO: is this really necessary ?
		ORDERNUMBER=$((ORDERNUMBER+10))
	fi

    pat="${patname}${EXTENSION}-%{version}-%{release}.%{_target_cpu}.pat"
    target="%buildroot/CD1/suse/setup/descr/$pat"
    xmltarget="%buildroot/%_datadir/%name/repodata/$patname${EXTENSION}"

	#############################
	#     generation starts
	#############################

    #
    # the "normal" patterns for the media
    #
	# top header
	echo "# %{global_name} Pattern %{version}${EXTENSION}-%{release}.%{_target_cpu} -- (c) $YEAR %{vendor}" > $target
	echo -n "# generated on " >> $target
	date >> $target
	echo >> $target
	echo "=Ver: 5.0" >> $target
	echo >> $target
	echo "=Pat: ${EXTENSION#-*} $patname %{version} %{release} %{_target_cpu}" >> $target
	# Category, summary and description must be present
    for tag in Cat Ico Sum Vis Ord; do
        if [ -f $tag ]; then
            echo >> $target
            echo -n "=${tag}: " >> $target
            cat $tag >> $target
        fi
    done
	if [ -f Des ]; then
		echo >> $target
		echo "+Des:" >> $target
		cat Des >> $target
		echo "-Des:" >> $target
	fi
	# now the translations
	# for supported languages see: https://forgesvn1.novell.com/svn/suse-i18n/trunk/yast/
	for tag in $(ls Cat.*); do
        echo >> $target
        echo -n "=${tag}: " >> $target
        cat $tag >> $target
	done
	for tag in $(ls Sum.*); do 
    	echo >> $target
    	echo -n "=${tag}: " >> $target
    	cat $tag >> $target
	done
	for tag in $(ls Des.*); do
		echo >> $target
        echo "+${tag}:" >> $target
        cat $tag >> $target
	    echo "-${tag}:" >> $target
	done
	# the interesting part: dependencies
    for tag in Fre Prv Req Rec Con Ext Inc Obs Sug Sup Prc Prq Psg; do
      test -f $TMPFILE && rm $TMPFILE
	  test -f ${TMPFILE}2 && rm ${TMPFILE}2
      if [ -f "$tag" ]; then
        sort -u $tag > $TMPFILE
	  fi
	  # check if there is a file like "Prc+i586"
	  # packages listed in this file should be added 
	  # to the Tag if the pattern is build for i586
	  if [ -f "${tag}+%{_target_cpu}" ]; then
		sort -u ${tag}+%{_target_cpu} >> $TMPFILE
	  fi
	  # check if there is a file like "Prc-x86_64"
	  # packages listed in this file should be removed
	  # from the Tag if the pattern is build for x86_64
	  if [ -f "${tag}-%{_target_cpu}" ]; then
		for i in $(cat ${tag}-%{_target_cpu}); do
			grep -vw $i $TMPFILE > ${TMPFILE}2
			mv ${TMPFILE}2 $TMPFILE
		done
	  fi
	  # now get it all together
	  # whatch for packages with version informations
	  # "kernel-default >= 2.6.25" for example
	  if [ -f "${TMPFILE}" ]; then
		echo >> $target
		echo "+${tag}:" >> $target
	  	sort -u ${TMPFILE} | while read a b;
	  	do
			if [ x"$b" = x"" ]; then
				echo "${a}${EXTENSION}"
			else
	        	echo "${a}${EXTENSION} $b"
			fi
		done >> $target
        echo "-${tag}:" >> $target
      fi
      if [ "$EXTENSION" != "" ]; then
		if [ ! -f ${tag} ]; then
			case ${tag} in 
				Sup)
					echo "+${tag}:" >> $target
					echo "${EXTENSION}" >> $target
					echo "-${tag}:" >> $target
				;;
				Fre)
					echo "+${tag}:" >> $target
					echo "${patname}" >> $target
					echo "-${tag}:" >> $target
				;;
			esac
		fi
	  fi
    done
    #
    # now the xml pattern for buildservice
    #
	echo "<pattern" >> $xmltarget
	echo " xmlns=\"http://novell.com/package/metadata/suse/pattern\"" >> $xmltarget
	echo " xmlns:rpm=\"http://linux.duke.edu/metadata/rpm\">" >> $xmltarget
    # Pattern name
    if [ -f Sum ]; then
        echo -n " <name>" >> $xmltarget
        cat Sum | tr -d "\n" >> $xmltarget
        echo "</name>" >> $xmltarget  
    else
        echo " <name>$patname</name>" >> $xmltarget
    fi
	# Summary
	if [ -f Sum ]; then
	  echo -n " <summary>" >> $xmltarget
	  cat Sum | tr -d "\n" >> $xmltarget
	  echo " </summary>" >> $xmltarget
#	  for i in $(ls Sum.*); do
#		if [ -f $i ]; then
#			echo -n " <summary lang=\"${i/Sum./}\">" >> $xmltarget
#			cat $i | tr -d "\n" >> $xmltarget
#			echo " </summary>" >> $xmltarget
#		fi
#	  done
	fi
	# Description
	if [ -f Des ]; then
	  echo -n " <description>" >> $xmltarget
	  cat Des | tr -d "\n" >> $xmltarget
	  echo " </description>"  >> $xmltarget
#	  for i in $(ls Des.*); do
#	      echo -n " <description lang=\"${i/Des./}\">" >> $xmltarget
#		  cat $i | tr -d "\n" >> $xmltarget
#          echo " </description>"  >> $xmltarget
#	  done
	fi
	# Visible
	if [ "$(cat Vis)" == "true" ]; then
		echo " <uservisible/>" >> $xmltarget
	fi
	# Category
	if [ -f Cat ]; then 
	  echo -n " <category>" >> $xmltarget
	  cat Cat | tr -d "\n" >> $xmltarget
	  echo " </category>" >> $xmltarget
#	  for i in $(ls Cat.*); do
#		echo -n " <category lang=\"${i/Cat./}\">" >> $xmltarget
#		cat $i | tr -d "\n" >> $xmltarget
#		echo " </category>" >> $xmltarget
#	  done
	fi

	# the interesting part: dependencies
    for tag in Prv Req Rec Con Ext Fre Inc Obs Sug Sup Prc Prq Psg; do
		if [ -f $tag ]; then
			case $tag in 
				Prv)
				TAG="rpm:provides"
				KIND="pattern"
				;;
				Req)
				TAG="rpm:requires"
				KIND="pattern"
				;; 
				Rec)
				TAG="rpm:recommends"
				KIND="pattern"
				;;
				Con)
				TAG="rpm:conflicts"
				KIND="pattern"
				;;
				Ext)
				TAG="rpm:extends"
				KIND="pattern"
				;;
				Fre)
				TAG="rpm:freshens"
				KIND="pattern"
				;;
				Inc) 
				TAG="rpm:freshens"
				KIND="pattern"
				;;
				Obs) 
				TAG="rpm:obsoletes"
				KIND="pattern"
				;;
				Sug) 
				TAG="rpm:suggests"
				KIND="pattern"
				;;
				Sup) 
				TAG="rpm:supplements"
				KIND="pattern"
				;;
				Prc) 
				TAG="rpm:recommends"
				KIND=""
				;;
				Prq) 
				TAG="rpm:requires"
				KIND=""
				;;
				Psg)
				TAG="rpm:suggests"
				KIND=""
				;;
			esac
			if [ "$KIND" != "" ]; then
				PRE="${KIND}:"
			else
				PRE=""
			fi
			echo " <$TAG>" >> $xmltarget
			test -f $TMPFILE && rm $TMPFILE
			sort -u $tag > $TMPFILE
			for entry in $(cat $TMPFILE); do
				echo "  <rpm:entry name=\"${PRE}${entry}\"/>" >> $xmltarget
                %if 0%{?create_packagelist}
                  if [ x"$KIND" = x"package" ]; then
                    echo "  <package name=\"$entry\"/>" >> $LIST
                  fi
                %endif
			done
			echo " </$TAG>" >> $xmltarget
		fi
	done
	echo "</pattern>" >> $xmltarget
	popd 1>/dev/null
  done
}

%if 0%{?create_packagelist}
  LIST="%buildroot/%_datadir/%name/%name.xml"
  echo "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" >> $LIST
  echo "<group name=\"%name\">" >> $LIST 
  echo " <packagelist id=\"%name\">" >> $LIST
%endif

create_pattern

%if 0%{?create_xxbit_pattern}
%ifarch ia64
  EXTENSION="-x86"
%endif
%ifarch ppc
  EXTENSION="-64bit"
%endif
%ifarch s390x
  EXTENSION="-32bit"
%endif
%ifarch x86_64
  EXTENSION="-32bit"
%endif
%endif

if [ "$EXTENSION" != "" ]; then
	create_pattern
fi

%if 0%{?create_packagelist}
  echo " </packagelist>" >> $LIST
  echo "</group>" >> $LIST
%endif

pushd %buildroot/CD1/suse/setup/descr 1>/dev/null
# since openSUSE 11.0 all patterns are collected in one file
%if 0%{?suse_version} > 1030
  ALL_NAME=%{all_in_one_pattern_name}
  if [ -f "$ALL_NAME-%{version}-%{release}.%{_target_cpu}.pat" ]; then
    echo "pattern $ALL_NAME-%{version}-%{release}.%{_target_cpu}.pat exists"
    exit 1
  else
    for i in *.pat; do
      cat $i >> $ALL_NAME-%{version}-%{release}.%{_target_cpu}.pat
      rm $i
    done
  fi
%endif
# since openSUSE 10.3, pattern files are compressed...
%if 0%{?suse_version} > 1020
	gzip *.pat
%endif
popd 1>/dev/null

%clean
rm -rf %buildroot

%files
%defattr(-,root,root)
%dir /CD1
%dir /CD1/suse
%dir /CD1/suse/setup
%dir /CD1/suse/setup/descr
/CD1/suse/setup/descr/*
%_datadir/%name/

%changelog
* Sun Dec 15 2013 lars@linux-schulserver.de
- use muse2 instead of muse
* Sun Jul 14 2013 lars@linux-schulserver.de
- move obsolete sabayon from Required to Recommended
* Sat Jan 12 2013 lars@linux-schulserver.de
- celestia is renamed to kde3-celestia
* Mon Dec 10 2012 lars@linux-schulserver.de
- added einstein, fritzing and krecipes
* Thu Feb 16 2012 lars@linux-schulserver.de
- switch from gambas2 to gambas3
* Thu Jun 11 2009 lars@linux-schulserver.de
- build correct OBS pattern files, too
* Wed Apr 29 2009 lars@linux-schulserver.de
- added additional sugar activities and gabble packages
* Sun Apr  5 2009 lars@linux-schulserver.de
- use %%name for packagelist.xml
* Sun Mar 15 2009 lars@linux-schulserver.de
- added italian translations for sugar
- added opensuse-education-tools, fet
* Tue Mar 10 2009 lars@linux-schulserver.de
- added first sugar pattern
* Fri Dec 12 2008 lars@linux-schulserver.de
- added canorus to youth-education-desktop (Prc)
- added gnome-quod and gmult to gnome-education-desktop (Prc)
-  added fl_teachertool to education-desktop (Psg)
* Fri Nov 28 2008 lars@linux-schulserver.de
- added scratch
* Fri Nov 14 2008 lars@linux-schulserver.de
- handle whitespaces after package files for SLE10
* Sun Oct 26 2008 lars@linux-schulserver.de
- create packagelist.xml
* Thu Oct  2 2008 lars@linux-schulserver.de
- added fl_teachertool as suggested in education-desktop
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Wed Sep 10 2008 lars@linux-schulserver.de
- added last packages for 11.0 release:
  brainworkshop, iTest and openSUSE-Education-release
* Mon Sep  8 2008 lars@linux-schulserver.de
- moved GNS3, R and fet to youth instead installing it everywhere
* Fri Aug  8 2008 lars@linux-schulserver.de
- follow James suggestions
- added GNS3 on pattern
* Wed Jul 16 2008 lars@linux-schulserver.de
- added Python-visual
* Wed Jun 18 2008 andrea@opensuse.org
- updated and improved Italian translation (Thanks to Anubisg1)
* Wed Jun 11 2008 lars@linux-schulserver.de
- updated and improved Russian translation (kkirill:1448)
* Wed May 21 2008 lars@linux-schulserver.de
- collect all patterns in one file for openSUSE > 1030
- use more macros to be 'universal'
- added VirtualLab, TuxMathScrabble, TuxWordSmith
- mark the IDEs as suggested
- increase version number
* Mon May 19 2008 lars@linux-schulserver.de
- fix rpm group
* Tue May 13 2008 lars@linux-schulserver.de
- added EXTRA_PROV
* Tue Apr 22 2008 lars@linux-schulserver.de
- added bluej
* Thu Apr 17 2008 lars@linux-schulserver.de
- some package reordering
- try to detect KDE and GNOME automatically and add the patterns
* Tue Apr  8 2008 lars@linux-schulserver.de
- added gbrainy
* Wed Mar 26 2008 lars@linux-schulserver.de
- added k3dsurf gambas2-ide xlogo
* Wed Mar 12 2008 lars@linux-schulserver.de
- introduction of gnome pattern (thanks to kkirill)
* Thu Jan 31 2008 lars@linux-schulserver.de
- added avogadro and klavaro
* Tue Jan 29 2008 lars@linux-schulserver.de
- added wine-doors
- added klogoturtle
* Mon Jan 14 2008 lars@linux-schulserver.de
- added russian translations
- added gnomesword, gpsim, fbreader and ktechlab
- added atomix
* Wed Dec 26 2007 lars@linux-schulserver.de
- added planets
- don't create patterns file
* Tue Dec 25 2007 lars@linux-schulserver.de
- place the ymp-pattern in %%_datadir/%%name/repodata, so the
  CD1 directoy contains just stuff that should find it's way to
  the media
* Sun Dec 23 2007 lars@linux-schulserver.de
- change group to Metapackage
* Sun Dec 23 2007 lars@linux-schulserver.de
- added geogebra and bibletime
- added MultiplicationStation
- added semanti
* Sun Dec 16 2007 lars@linux-schulserver.de
- YaST don't like whitespace chars behind the tags :-(
* Thu Dec 13 2007 lars@linux-schulserver.de
- new sort form for patfiles
- new creation form for ymp files:
  now also add pattern dependencies
- added tkgate
- added kst and kiosktool-edu-settings
- added xdrawchem, fraqtive
- added fpc, fpc-units and lazarus (Pascal)
* Sat Nov 24 2007 lars@linux-schulserver.de
- don't add ymp to the xml pattern name: is done by the bs
* Tue Nov 20 2007 lars@linux-schulserver.de
- use right tags for pattern files
* Tue Nov 20 2007 lars@linux-schulserver.de
- added kding to kde
* Fri Nov 16 2007 lars@suse.de
- added plutimikation to kids
* Thu Nov 15 2007 lrupp@suse.de
- added to kde-apps:
  kde4-kig, kde4-kmahjongg, kde4-kmines, kde4-kpat, kde4-kreversi,
  kde4-ksudoku, kde4-ktouch, kseg, quanta (kdewebdev3)
- added to youth: galculator
* Thu Nov  8 2007 lrupp@suse.de
- added to kids-pattern:
  + pysycache-themes-move
  + pysycache-themes-click
* Sun Nov  4 2007 lars@linux-schulserver.de
- remove wrongly added foobar from education-desktop
- remove edu-server from education-full (we just install all
  desktop packages now)
* Sat Oct 27 2007 lars@linux-schulserver.de
- added invisible pattern education-full:
  This pattern recommends all other patterns, so we can
  require and install it via the content file
* Tue Oct 23 2007 lrupp@suse.de
- added kdeutils3-extra to get kjots
- added kde4-kolourpaint
- added kde_games pattern as recommended to kde-edu pattern
- added enigma to kids pattern
- added xaos to youth pattern
* Mon Oct 22 2007 lrupp@suse.de
- added release-notes-edu as required package
* Fri Oct 19 2007 lars@linux-schulserver.de
- added kile to kde pattern
* Wed Oct 17 2007 lrupp@suse.de
- added missing Cat.de
- use patname instead of pat for =Pat tag
- added release-notes-edu to Required for Edu-Desktop
- require education-desktop in youth and kids pattern
* Fri Oct 12 2007 lrupp@suse.de
- compress pattern files for openSUSE > 10.2
* Mon Oct  8 2007 lrupp@suse.de
- moved latex-beamer and kde4-kalzium to Psg:
  + libcompoundviewer.so is needed for kde4-kalzium
  + latex-beamer is included in 10.3
- let the kids-pattern recommend the education base pattern
- added XaraLX to youth
* Thu Oct  4 2007 lrupp@suse.de
- splitted the complete patterns into small files
- create also xml-patterns for the buildservice
* Tue Aug 14 2007 lrupp@suse.de
- moved tuxmath from youth to kids
* Tue Aug 14 2007 lrupp@suse.de
- added littlewizard to kids-education-desktop
* Sun Aug 12 2007 lrupp@suse.de
- splitted the one big pattern into parts
  + kde-education-desktop.pat   : KDE Education software
  + kids-education-desktop.pat  : Software for 4-10 year old kids
  + youth-education-desktop.pat : Software for 11-14 year old kids
* Thu Jun 21 2007 lrupp@suse.de
- use "Education Desktop applications" for summary
* Wed Jun  6 2007 lrupp@suse.de
- adapt naming and some package ordering
* Sun May 20 2007 lrupp@suse.de
- create the Order numbers more dynamically
* Fri May 18 2007 lrupp@suse.de
- avoid umlauts at this early time
* Fri Apr 27 2007 lrupp@suse.de
- created initial version for Education Desktop
  + no translations
